import {editorialState, accessState} from '../props'
import {defaultFieldsets} from '../fieldsets'

export default {
  name: 'LinguisticObject',
  type: 'object',
  title: 'Tekst',
  titleEN: 'Text',
  fieldsets: defaultFieldsets,
  fields: [
    editorialState,
    accessState,
    {
      name: 'hasType',
      title: 'Klassifisert som',
      titleEN: 'Classified as',
      type: 'array',
      of: [
        {
          type: 'reference',
          to: [{type: 'TextType'}],
        },
      ],
      validation: (Rule) => Rule.required(),
    },
    {
      name: 'body',
      title: 'Tekst',
      titleEN: 'Body',
      type: 'blockContent',
    },
    {
      name: 'language',
      title: 'Språk',
      titleEN: 'Language',
      type: 'reference',
      to: [{type: 'Language'}],
      validation: (Rule) => Rule.required(),
    },
    {
      name: 'creator',
      title: 'Skaper',
      titleEN: 'Creator',
      description:
        'Registrer en eller flere aktører som har skapt dette dokumentet, gjerne med hvilken rolle de hadde.',
      type: 'array',
      of: [
        {
          type: 'ContributionAssignment',
        },
      ],
    },
    {
      name: 'publishedAt',
      title: 'Publikasjonsdato',
      titleEN: 'Published at',
      description: 'This can be used to schedule post for publishing',
      type: 'datetime',
    },
    {
      name: 'documentedIn',
      title: 'Dokumentert i',
      titleEN: 'Documented in',
      type: 'array',
      of: [{type: 'file'}],
    },
  ],
  preview: {
    select: {
      title: 'hasType.0.label.nor',
      blocks: 'body',
      lang: 'language.label.nor',
    },
    prepare(selection) {
      const {title, blocks, lang} = selection
      const block = blocks[0]

      return {
        title: block
          ? block.children
              .filter((child) => child._type === 'span')
              .map((span) => span.text)
              .join('')
          : 'No description',
        subtitle: `${title} ${lang ? 'på ' + lang : ''}`,
      }
    },
  },
}
