import Link from 'next/link'
import {Image, Badge, Box, Container, Flex, Heading} from '@chakra-ui/react'
import PortableTextBlock from '../PortableTextBlock'
import Cards from '../Cards'
import {imageBuilder} from '../../lib/sanity'

export default function Actor(item) {
  return (
    <Container 
      maxW="full" 
      py="10" 
      centerContent
    >
      <Flex pb="10">
        <Image
          boxSize="100"
          name={item.label}
          src={imageBuilder.image(item.image).height('200').width('200').url()}
        />
        <Box p={5}>
          <Heading fontSize={["2xl", "4xl", "5xl", "6xl"]}>
            <Link href={`/id/${item._id}`}>
              <a>{item.label}</a>
            </Link>
          </Heading>
          <Box d="flex" alignItems="baseline">
            {item.hasType &&
              item.hasType.map((type) => (
                <Badge key={type._id} borderRadius="full" px="2" colorScheme="teal">
                  {type.label?.nor}
                </Badge>
              ))}
            {!item.hasType && (
              <Badge borderRadius="full" px="2" colorScheme="teal">
                Person
              </Badge>
            )}
          </Box>
        </Box>
      </Flex>

      <Container maxW="lg">
        {item?.referredToBy?.map((ref) => (
          <PortableTextBlock key={ref._key} blocks={ref.body} />
        ))}
      </Container>
      
      {item.hasMember && item.hasMember.map((member) => (
        <Link href={member._id}>
          <a>{member.label}</a>
        </Link>
      ))}

      {item.mentionedIn && <Cards items={item.mentionedIn} />}
    </Container>
  )
}
